#!/bin/bash
# knoppix-install-extras - A light-weight text-based installation utility.

PATH="/bin:/sbin:/usr/bin:/usr/sbin"
export PATH

XDIALOG_HIGH_DIALOG_COMPAT=1
export XDIALOG_HIGH_DIALOG_COMPAT

XDIALOG_NO_GMSGS=1
export XDIALOG_NO_GMSGS

[ "`id -u`" != "0" ] && exec sudo -H "$0" "$@"

TMP="/tmp/knoppix-install-extras.tmp$$"

bailout(){
 rm -f "$TMP"
 exit $1
}

# Simple shell grep
stringinfile(){
 case "$(cat $2)" in *$1*) return 0;; esac
 return 1
}

# Language-specific messages
if [ -r /etc/sysconfig/i18n ]; then
 . /etc/sysconfig/i18n
elif [ -r /etc/default/locale ]; then
 . /etc/default/locale
fi

# Temporary workaround: zenity fails to understand isolatin strings :-(
# case "$LANG" in de*.UTF-8) export LANG=de_DE@euro LC_ALL=de_DE@euro;; esac
# to_utf8(){
# echo -e "$1" | iconv --to-code=utf-8
#}

case "$LANGUAGE" in
 de*) D_AMAROK="Audio-Jukebox"
      D_AUDACITY="Audacity Tonstudio"
      D_FLASH="Flash-Unterstützung für den Browser"
      D_KAFFEINE="KDE Multimedia-Player für verschiedene Videoformate und DVB"
      D_MPLAYER="Mplayer Audio/Video-Abspieler"
      D_OPENSHOT="Openshot Video Editor"
      D_FONTS="Windows Zeichensätze für OpenOffice"
      D_XBMC="XBMC Multimedia Center"
      D_TUXPAINT="Einfaches Zeichenprogramm für Kinder"
      D_FOOMATIC="Mehr Druckerbeschreibungen"
      D_INSTALL="inst."
      D_UPDATE="aktual."
      TITLE="Software installieren"
      BACKTITLE="Zusätzliche Software"
      INSTALL="Installieren"
      PACKAGE="Paket"
      DESCRIPTION="Beschreibung"
      ALLINSTALLED="
Alle hier angebotenen Zusatzprogramme sind bereits installiert,
bitte verweden Sie \"synaptic\" oder \"aptitude\", um weitere
Software nach Wunsch zu installieren."
      DISCLAIMER="
Die hier angegebenen Softwarekomponenten sind zwar im Internet
frei verfügbar, können aber aufgrund der Distributionslizenz
einzelner Bestandteile bzw. wegen Patentansprüchen möglicherweise
nach dem in Ihrem Land geltenden Recht nicht als Bestandteil einer
freien GNU/Linux Distribution beliebig verteilt werden.

Mit diesem Programm haben Sie die Möglichkeit, Ihr System
entsprechend nachzurüsten, Internetzugang vorausgesetzt.

Bitte Pakete zur Installation / zum Update auswählen:"
      ;;
   *) D_AMAROK="Music Jukebox"
      D_AUDACITY="Audacity sound studio"
      D_FLASH="Flash support for your browser"
      D_KAFFEINE="KDE Multimedia Player for different video formats and DVB"
      D_MPLAYER="Mplayer Audio/Video-Player"
      D_OPENSHOT="Openshot Video Editor"
      D_FONTS="Windows fonts for OpenOffice"
      D_XBMC="XBMC Multimedia Center"
      D_TUXPAINT="Simple drawing program for children"
      D_FOOMATIC="More printer drivers"
      D_INSTALL="install"
      D_UPDATE="update"
      TITLE="Install software"
      BACKTITLE="Additional Software"
      INSTALL="Install"
      PACKAGE="Package"
      DESCRIPTION="Description"
      ALLINSTALLED="
All additional programs offered here, are already installed.
Please use \"synaptic\" or \"aptitude\" to install more programs."
      DISCLAIMER="
The software components offered here are free and publically
available on the internet. But because of patents or
vendor-specific license restrictions, conforming to your
countries laws, it may not be possible to distribute them
as part of a free GNU/Linux distribution.

Using this program, you can add these components to your system,
povided that you have internet access.

Please select packages for installation:"
      ;;
esac

# package description
PRODUCTS=( \
"audacity" "$D_AUDACITY" \
"flashplugin-nonfree" "$D_FLASH" \
"mplayer" "$D_MPLAYER" \
"openshot" "$D_OPENSHOT" \
"ttf-mscorefonts-installer" "$D_FONTS" \
"tuxpaint" "$D_TUXPAINT" \
"foomatic-db-gutenprint" "$D_FOOMATIC" \
"xbmc" "$D_XBMC" \
)

MENU=()
let count=0

if [ -n "$DISPLAY" ] && type zenity >/dev/null 2>&1; then # Graphical version
 ICON="/usr/share/icons/knoppix-install-extras.xpm"
 [ -r "$ICON" ] && ICON="--window-icon=$ICON" || ICON=""
 for ((i=0; i<${#PRODUCTS[@]}; i+=2)); do
  INSTALL="$D_INSTALL"
  [ -f /var/lib/dpkg/info/"${PRODUCTS[$i]}".list ] && INSTALL="$D_UPDATE"
  MENU[$((count++))]="FALSE" 
  MENU[$((count++))]="${PRODUCTS[$i]}" 
  MENU[$((count++))]="${PRODUCTS[$((i+1))]} (${INSTALL})" 
 done
 if [ "${#MENU[@]}" = "0" ]; then
  zenity --title="$TITLE" $ICON --info --text="$ALLINSTALLED"
  bailout 0
 fi
 zenity --height=450 --width=550 --title="$TITLE" $ICON --list --text="$BACKTITLE\n$DISCLAIMER" --column="$INSTALL" --column="$PACKAGE" --column="$DESCRIPTION" --checklist --separator="/" "${MENU[@]}" >"$TMP" || { cat "$TMP"; bailout 0; }
else # Text dialog
 for ((i=0; i<${#PRODUCTS[@]}; i+=2)); do
  INSTALL="$D_INSTALL"
  [ -f /var/lib/dpkg/info/"${PRODUCTS[$i]}".list ] && INSTALL="$D_UPDATE"
  MENU[$((count++))]="${PRODUCTS[$i]}" 
  MENU[$((count++))]="${PRODUCTS[$((i+1))]} (${INSTALL})" 
  MENU[$((count++))]="off" 
 done
 if [ "${#MENU[@]}" = "0" ]; then
  dialog --title "$TITLE" --msgbox "$ALLINSTALLED" 10 45
  bailout 0
 fi
 dialog --ok-label "$INSTALL" --yes-label "$INSTALL" --title "$TITLE" --backtitle "$BACKTITLE" --checklist  "$DISCLAIMER" 0 75 0 "${MENU[@]}" 2>"$TMP" || bailout 0
fi

PROGS=()
IFS=/ read -a PROGS < "$TMP"

rm -f "$TMP"
exec knoppix-checkinstall "${PROGS[@]}"
